==> devops-client-java-1.0.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineSpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1PipelineSpecFluent<A extends V1alpha1PipelineSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildCause instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineCause getCause();
    public V1alpha1PipelineCause buildCause();
    public A withCause(V1alpha1PipelineCause cause);
    public Boolean hasCause();
    public V1alpha1PipelineSpecFluent.CauseNested<A> withNewCause();
    public V1alpha1PipelineSpecFluent.CauseNested<A> withNewCauseLike(V1alpha1PipelineCause item);
    public V1alpha1PipelineSpecFluent.CauseNested<A> editCause();
    public V1alpha1PipelineSpecFluent.CauseNested<A> editOrNewCause();
    public V1alpha1PipelineSpecFluent.CauseNested<A> editOrNewCauseLike(V1alpha1PipelineCause item);
    public A addToHooks(int index,V1alpha1PipelineHook item);
    public A setToHooks(int index,V1alpha1PipelineHook item);
    public A addToHooks(V1alpha1PipelineHook... items);
    public A addAllToHooks(Collection<V1alpha1PipelineHook> items);
    public A removeFromHooks(V1alpha1PipelineHook... items);
    public A removeAllFromHooks(Collection<V1alpha1PipelineHook> items);
    
/**
 * This method has been deprecated, please use method buildHooks instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineHook> getHooks();
    public List<V1alpha1PipelineHook> buildHooks();
    public V1alpha1PipelineHook buildHook(int index);
    public V1alpha1PipelineHook buildFirstHook();
    public V1alpha1PipelineHook buildLastHook();
    public V1alpha1PipelineHook buildMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    public Boolean hasMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    public A withHooks(List<V1alpha1PipelineHook> hooks);
    public A withHooks(V1alpha1PipelineHook... hooks);
    public Boolean hasHooks();
    public V1alpha1PipelineSpecFluent.HooksNested<A> addNewHook();
    public V1alpha1PipelineSpecFluent.HooksNested<A> addNewHookLike(V1alpha1PipelineHook item);
    public V1alpha1PipelineSpecFluent.HooksNested<A> setNewHookLike(int index,V1alpha1PipelineHook item);
    public V1alpha1PipelineSpecFluent.HooksNested<A> editHook(int index);
    public V1alpha1PipelineSpecFluent.HooksNested<A> editFirstHook();
    public V1alpha1PipelineSpecFluent.HooksNested<A> editLastHook();
    public V1alpha1PipelineSpecFluent.HooksNested<A> editMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildJenkinsBinding instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1LocalObjectReference getJenkinsBinding();
    public V1alpha1LocalObjectReference buildJenkinsBinding();
    public A withJenkinsBinding(V1alpha1LocalObjectReference jenkinsBinding);
    public Boolean hasJenkinsBinding();
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> withNewJenkinsBinding();
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> withNewJenkinsBindingLike(V1alpha1LocalObjectReference item);
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> editJenkinsBinding();
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> editOrNewJenkinsBinding();
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> editOrNewJenkinsBindingLike(V1alpha1LocalObjectReference item);
    public A addToParameters(int index,V1alpha1PipelineParameter item);
    public A setToParameters(int index,V1alpha1PipelineParameter item);
    public A addToParameters(V1alpha1PipelineParameter... items);
    public A addAllToParameters(Collection<V1alpha1PipelineParameter> items);
    public A removeFromParameters(V1alpha1PipelineParameter... items);
    public A removeAllFromParameters(Collection<V1alpha1PipelineParameter> items);
    
/**
 * This method has been deprecated, please use method buildParameters instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineParameter> getParameters();
    public List<V1alpha1PipelineParameter> buildParameters();
    public V1alpha1PipelineParameter buildParameter(int index);
    public V1alpha1PipelineParameter buildFirstParameter();
    public V1alpha1PipelineParameter buildLastParameter();
    public V1alpha1PipelineParameter buildMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public Boolean hasMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public A withParameters(List<V1alpha1PipelineParameter> parameters);
    public A withParameters(V1alpha1PipelineParameter... parameters);
    public Boolean hasParameters();
    public V1alpha1PipelineSpecFluent.ParametersNested<A> addNewParameter();
    public V1alpha1PipelineSpecFluent.ParametersNested<A> addNewParameterLike(V1alpha1PipelineParameter item);
    public V1alpha1PipelineSpecFluent.ParametersNested<A> setNewParameterLike(int index,V1alpha1PipelineParameter item);
    public V1alpha1PipelineSpecFluent.ParametersNested<A> editParameter(int index);
    public V1alpha1PipelineSpecFluent.ParametersNested<A> editFirstParameter();
    public V1alpha1PipelineSpecFluent.ParametersNested<A> editLastParameter();
    public V1alpha1PipelineSpecFluent.ParametersNested<A> editMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildPipelineConfig instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1LocalObjectReference getPipelineConfig();
    public V1alpha1LocalObjectReference buildPipelineConfig();
    public A withPipelineConfig(V1alpha1LocalObjectReference pipelineConfig);
    public Boolean hasPipelineConfig();
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> withNewPipelineConfig();
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> withNewPipelineConfigLike(V1alpha1LocalObjectReference item);
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> editPipelineConfig();
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> editOrNewPipelineConfig();
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> editOrNewPipelineConfigLike(V1alpha1LocalObjectReference item);
    public String getRunPolicy();
    public A withRunPolicy(String runPolicy);
    public Boolean hasRunPolicy();
    public A withNewRunPolicy(String arg1);
    public A withNewRunPolicy(StringBuilder arg1);
    public A withNewRunPolicy(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSource getSource();
    public V1alpha1PipelineSource buildSource();
    public A withSource(V1alpha1PipelineSource source);
    public Boolean hasSource();
    public V1alpha1PipelineSpecFluent.SourceNested<A> withNewSource();
    public V1alpha1PipelineSpecFluent.SourceNested<A> withNewSourceLike(V1alpha1PipelineSource item);
    public V1alpha1PipelineSpecFluent.SourceNested<A> editSource();
    public V1alpha1PipelineSpecFluent.SourceNested<A> editOrNewSource();
    public V1alpha1PipelineSpecFluent.SourceNested<A> editOrNewSourceLike(V1alpha1PipelineSource item);
    
/**
 * This method has been deprecated, please use method buildStrategy instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineStrategy getStrategy();
    public V1alpha1PipelineStrategy buildStrategy();
    public A withStrategy(V1alpha1PipelineStrategy strategy);
    public Boolean hasStrategy();
    public V1alpha1PipelineSpecFluent.StrategyNested<A> withNewStrategy();
    public V1alpha1PipelineSpecFluent.StrategyNested<A> withNewStrategyLike(V1alpha1PipelineStrategy item);
    public V1alpha1PipelineSpecFluent.StrategyNested<A> editStrategy();
    public V1alpha1PipelineSpecFluent.StrategyNested<A> editOrNewStrategy();
    public V1alpha1PipelineSpecFluent.StrategyNested<A> editOrNewStrategyLike(V1alpha1PipelineStrategy item);
    public A addToTriggers(int index,V1alpha1PipelineTrigger item);
    public A setToTriggers(int index,V1alpha1PipelineTrigger item);
    public A addToTriggers(V1alpha1PipelineTrigger... items);
    public A addAllToTriggers(Collection<V1alpha1PipelineTrigger> items);
    public A removeFromTriggers(V1alpha1PipelineTrigger... items);
    public A removeAllFromTriggers(Collection<V1alpha1PipelineTrigger> items);
    
/**
 * This method has been deprecated, please use method buildTriggers instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineTrigger> getTriggers();
    public List<V1alpha1PipelineTrigger> buildTriggers();
    public V1alpha1PipelineTrigger buildTrigger(int index);
    public V1alpha1PipelineTrigger buildFirstTrigger();
    public V1alpha1PipelineTrigger buildLastTrigger();
    public V1alpha1PipelineTrigger buildMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);
    public Boolean hasMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);
    public A withTriggers(List<V1alpha1PipelineTrigger> triggers);
    public A withTriggers(V1alpha1PipelineTrigger... triggers);
    public Boolean hasTriggers();
    public V1alpha1PipelineSpecFluent.TriggersNested<A> addNewTrigger();
    public V1alpha1PipelineSpecFluent.TriggersNested<A> addNewTriggerLike(V1alpha1PipelineTrigger item);
    public V1alpha1PipelineSpecFluent.TriggersNested<A> setNewTriggerLike(int index,V1alpha1PipelineTrigger item);
    public V1alpha1PipelineSpecFluent.TriggersNested<A> editTrigger(int index);
    public V1alpha1PipelineSpecFluent.TriggersNested<A> editFirstTrigger();
    public V1alpha1PipelineSpecFluent.TriggersNested<A> editLastTrigger();
    public V1alpha1PipelineSpecFluent.TriggersNested<A> editMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);

    public interface CauseNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineCauseFluent<V1alpha1PipelineSpecFluent.CauseNested<N>>{

        
    public N and();    public N endCause();
}
    public interface HooksNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineHookFluent<V1alpha1PipelineSpecFluent.HooksNested<N>>{

        
    public N and();    public N endHook();
}
    public interface JenkinsBindingNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1LocalObjectReferenceFluent<V1alpha1PipelineSpecFluent.JenkinsBindingNested<N>>{

        
    public N and();    public N endJenkinsBinding();
}
    public interface ParametersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineParameterFluent<V1alpha1PipelineSpecFluent.ParametersNested<N>>{

        
    public N and();    public N endParameter();
}
    public interface PipelineConfigNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1LocalObjectReferenceFluent<V1alpha1PipelineSpecFluent.PipelineConfigNested<N>>{

        
    public N and();    public N endPipelineConfig();
}
    public interface SourceNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceFluent<V1alpha1PipelineSpecFluent.SourceNested<N>>{

        
    public N and();    public N endSource();
}
    public interface StrategyNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineStrategyFluent<V1alpha1PipelineSpecFluent.StrategyNested<N>>{

        
    public N and();    public N endStrategy();
}
    public interface TriggersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTriggerFluent<V1alpha1PipelineSpecFluent.TriggersNested<N>>{

        
    public N and();    public N endTrigger();
}


}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineSpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1PipelineSpecFluent<A extends V1alpha1PipelineSpecFluent<A>> extends Fluent<A>{


    public Boolean isCancel();
    public A withCancel(Boolean cancel);
    public Boolean hasCancel();
    public A withNewCancel(String arg1);
    public A withNewCancel(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildCause instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineCause getCause();
    public V1alpha1PipelineCause buildCause();
    public A withCause(V1alpha1PipelineCause cause);
    public Boolean hasCause();
    public V1alpha1PipelineSpecFluent.CauseNested<A> withNewCause();
    public V1alpha1PipelineSpecFluent.CauseNested<A> withNewCauseLike(V1alpha1PipelineCause item);
    public V1alpha1PipelineSpecFluent.CauseNested<A> editCause();
    public V1alpha1PipelineSpecFluent.CauseNested<A> editOrNewCause();
    public V1alpha1PipelineSpecFluent.CauseNested<A> editOrNewCauseLike(V1alpha1PipelineCause item);
    public A addToHooks(int index,V1alpha1PipelineHook item);
    public A setToHooks(int index,V1alpha1PipelineHook item);
    public A addToHooks(V1alpha1PipelineHook... items);
    public A addAllToHooks(Collection<V1alpha1PipelineHook> items);
    public A removeFromHooks(V1alpha1PipelineHook... items);
    public A removeAllFromHooks(Collection<V1alpha1PipelineHook> items);
    
/**
 * This method has been deprecated, please use method buildHooks instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineHook> getHooks();
    public List<V1alpha1PipelineHook> buildHooks();
    public V1alpha1PipelineHook buildHook(int index);
    public V1alpha1PipelineHook buildFirstHook();
    public V1alpha1PipelineHook buildLastHook();
    public V1alpha1PipelineHook buildMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    public Boolean hasMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    public A withHooks(List<V1alpha1PipelineHook> hooks);
    public A withHooks(V1alpha1PipelineHook... hooks);
    public Boolean hasHooks();
    public V1alpha1PipelineSpecFluent.HooksNested<A> addNewHook();
    public V1alpha1PipelineSpecFluent.HooksNested<A> addNewHookLike(V1alpha1PipelineHook item);
    public V1alpha1PipelineSpecFluent.HooksNested<A> setNewHookLike(int index,V1alpha1PipelineHook item);
    public V1alpha1PipelineSpecFluent.HooksNested<A> editHook(int index);
    public V1alpha1PipelineSpecFluent.HooksNested<A> editFirstHook();
    public V1alpha1PipelineSpecFluent.HooksNested<A> editLastHook();
    public V1alpha1PipelineSpecFluent.HooksNested<A> editMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildJenkinsBinding instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1LocalObjectReference getJenkinsBinding();
    public V1alpha1LocalObjectReference buildJenkinsBinding();
    public A withJenkinsBinding(V1alpha1LocalObjectReference jenkinsBinding);
    public Boolean hasJenkinsBinding();
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> withNewJenkinsBinding();
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> withNewJenkinsBindingLike(V1alpha1LocalObjectReference item);
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> editJenkinsBinding();
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> editOrNewJenkinsBinding();
    public V1alpha1PipelineSpecFluent.JenkinsBindingNested<A> editOrNewJenkinsBindingLike(V1alpha1LocalObjectReference item);
    public A addToParameters(int index,V1alpha1PipelineParameter item);
    public A setToParameters(int index,V1alpha1PipelineParameter item);
    public A addToParameters(V1alpha1PipelineParameter... items);
    public A addAllToParameters(Collection<V1alpha1PipelineParameter> items);
    public A removeFromParameters(V1alpha1PipelineParameter... items);
    public A removeAllFromParameters(Collection<V1alpha1PipelineParameter> items);
    
/**
 * This method has been deprecated, please use method buildParameters instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineParameter> getParameters();
    public List<V1alpha1PipelineParameter> buildParameters();
    public V1alpha1PipelineParameter buildParameter(int index);
    public V1alpha1PipelineParameter buildFirstParameter();
    public V1alpha1PipelineParameter buildLastParameter();
    public V1alpha1PipelineParameter buildMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public Boolean hasMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public A withParameters(List<V1alpha1PipelineParameter> parameters);
    public A withParameters(V1alpha1PipelineParameter... parameters);
    public Boolean hasParameters();
    public V1alpha1PipelineSpecFluent.ParametersNested<A> addNewParameter();
    public V1alpha1PipelineSpecFluent.ParametersNested<A> addNewParameterLike(V1alpha1PipelineParameter item);
    public V1alpha1PipelineSpecFluent.ParametersNested<A> setNewParameterLike(int index,V1alpha1PipelineParameter item);
    public V1alpha1PipelineSpecFluent.ParametersNested<A> editParameter(int index);
    public V1alpha1PipelineSpecFluent.ParametersNested<A> editFirstParameter();
    public V1alpha1PipelineSpecFluent.ParametersNested<A> editLastParameter();
    public V1alpha1PipelineSpecFluent.ParametersNested<A> editMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildPipelineConfig instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1LocalObjectReference getPipelineConfig();
    public V1alpha1LocalObjectReference buildPipelineConfig();
    public A withPipelineConfig(V1alpha1LocalObjectReference pipelineConfig);
    public Boolean hasPipelineConfig();
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> withNewPipelineConfig();
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> withNewPipelineConfigLike(V1alpha1LocalObjectReference item);
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> editPipelineConfig();
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> editOrNewPipelineConfig();
    public V1alpha1PipelineSpecFluent.PipelineConfigNested<A> editOrNewPipelineConfigLike(V1alpha1LocalObjectReference item);
    public String getRunPolicy();
    public A withRunPolicy(String runPolicy);
    public Boolean hasRunPolicy();
    public A withNewRunPolicy(String arg1);
    public A withNewRunPolicy(StringBuilder arg1);
    public A withNewRunPolicy(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSource getSource();
    public V1alpha1PipelineSource buildSource();
    public A withSource(V1alpha1PipelineSource source);
    public Boolean hasSource();
    public V1alpha1PipelineSpecFluent.SourceNested<A> withNewSource();
    public V1alpha1PipelineSpecFluent.SourceNested<A> withNewSourceLike(V1alpha1PipelineSource item);
    public V1alpha1PipelineSpecFluent.SourceNested<A> editSource();
    public V1alpha1PipelineSpecFluent.SourceNested<A> editOrNewSource();
    public V1alpha1PipelineSpecFluent.SourceNested<A> editOrNewSourceLike(V1alpha1PipelineSource item);
    
/**
 * This method has been deprecated, please use method buildStrategy instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineStrategy getStrategy();
    public V1alpha1PipelineStrategy buildStrategy();
    public A withStrategy(V1alpha1PipelineStrategy strategy);
    public Boolean hasStrategy();
    public V1alpha1PipelineSpecFluent.StrategyNested<A> withNewStrategy();
    public V1alpha1PipelineSpecFluent.StrategyNested<A> withNewStrategyLike(V1alpha1PipelineStrategy item);
    public V1alpha1PipelineSpecFluent.StrategyNested<A> editStrategy();
    public V1alpha1PipelineSpecFluent.StrategyNested<A> editOrNewStrategy();
    public V1alpha1PipelineSpecFluent.StrategyNested<A> editOrNewStrategyLike(V1alpha1PipelineStrategy item);
    public A addToTriggers(int index,V1alpha1PipelineTrigger item);
    public A setToTriggers(int index,V1alpha1PipelineTrigger item);
    public A addToTriggers(V1alpha1PipelineTrigger... items);
    public A addAllToTriggers(Collection<V1alpha1PipelineTrigger> items);
    public A removeFromTriggers(V1alpha1PipelineTrigger... items);
    public A removeAllFromTriggers(Collection<V1alpha1PipelineTrigger> items);
    
/**
 * This method has been deprecated, please use method buildTriggers instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineTrigger> getTriggers();
    public List<V1alpha1PipelineTrigger> buildTriggers();
    public V1alpha1PipelineTrigger buildTrigger(int index);
    public V1alpha1PipelineTrigger buildFirstTrigger();
    public V1alpha1PipelineTrigger buildLastTrigger();
    public V1alpha1PipelineTrigger buildMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);
    public Boolean hasMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);
    public A withTriggers(List<V1alpha1PipelineTrigger> triggers);
    public A withTriggers(V1alpha1PipelineTrigger... triggers);
    public Boolean hasTriggers();
    public V1alpha1PipelineSpecFluent.TriggersNested<A> addNewTrigger();
    public V1alpha1PipelineSpecFluent.TriggersNested<A> addNewTriggerLike(V1alpha1PipelineTrigger item);
    public V1alpha1PipelineSpecFluent.TriggersNested<A> setNewTriggerLike(int index,V1alpha1PipelineTrigger item);
    public V1alpha1PipelineSpecFluent.TriggersNested<A> editTrigger(int index);
    public V1alpha1PipelineSpecFluent.TriggersNested<A> editFirstTrigger();
    public V1alpha1PipelineSpecFluent.TriggersNested<A> editLastTrigger();
    public V1alpha1PipelineSpecFluent.TriggersNested<A> editMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);

    public interface CauseNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineCauseFluent<V1alpha1PipelineSpecFluent.CauseNested<N>>{

        
    public N and();    public N endCause();
}
    public interface HooksNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineHookFluent<V1alpha1PipelineSpecFluent.HooksNested<N>>{

        
    public N and();    public N endHook();
}
    public interface JenkinsBindingNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1LocalObjectReferenceFluent<V1alpha1PipelineSpecFluent.JenkinsBindingNested<N>>{

        
    public N and();    public N endJenkinsBinding();
}
    public interface ParametersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineParameterFluent<V1alpha1PipelineSpecFluent.ParametersNested<N>>{

        
    public N and();    public N endParameter();
}
    public interface PipelineConfigNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1LocalObjectReferenceFluent<V1alpha1PipelineSpecFluent.PipelineConfigNested<N>>{

        
    public N and();    public N endPipelineConfig();
}
    public interface SourceNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceFluent<V1alpha1PipelineSpecFluent.SourceNested<N>>{

        
    public N and();    public N endSource();
}
    public interface StrategyNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineStrategyFluent<V1alpha1PipelineSpecFluent.StrategyNested<N>>{

        
    public N and();    public N endStrategy();
}
    public interface TriggersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTriggerFluent<V1alpha1PipelineSpecFluent.TriggersNested<N>>{

        
    public N and();    public N endTrigger();
}


}
